from setuptools import setup

setup(
    name="capytal",
    version="0.0.0",
    description="A package for building complex stochastic models",
    author="Dan Gelderd",
    url="https://danielgelderd@dev.azure.com/danielgelderd/capytal/_git/capytal",
    packages=[],  # Empty list - no packages included
)